pocketpose.converters.onnx2tf - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.converters.onnx2tf`

## Module Contents

### Classes

`ONNX2TFConverter` | Converts ONNX models to TensorFlow format.

class pocketpose.converters.onnx2tf.ONNX2TFConverter(overwrite=True, log_level=logging.INFO)

  Bases: `pocketpose.converters.base_converter.BaseConverter`

  Converts ONNX models to TensorFlow format.

  _sanitize(onnx_model)
  _convert(model, save_path, *args, **kwargs)

    Converts an ONNX model to TensorFlow format (.pb) and saves it to disk.

    Args:

      model (str): Path to the ONNX model to convert save_path (str): Path to save the converted model to. This should be a directory.

    Returns:

      save_path (str): Path to the converted model (same as the input save path) if successful.